*================================================================*
* SAS programmer: James Nguyen, USEPA                            *
*                                                                *
* Project: OP inhibition studies                                 *
*                                                                *
* Chemical: Malaoxon                              *
*                                                                *
* Descriptions:                                                  *
*     - run the selected (Exponent) final models                 *
*     - perform regression diagnostics                           *
*     - calculated ki values from human vs. rat analysis         *
*                                                                *
* Date: March 2020                                               *
*===============================================================*;
option formdlim="=" ls=100 ps=100 nodate nonumber;

%include "C:\JcohenBACKUP-Destination\toxico\whitepaper\All CEB Analyses\Newcode\Diagnostics3.SAS";

libname EPA "C:\JcohenBACKUP-Destination\toxico\whitepaper\All CEB Analyses\kapp data";


/****************************************************************************/
/* Final NLMIXED Model                                                      */
/****************************************************************************/

data malaoxon;
     set epa.malaoxon;
run;
proc sort data=malaoxon;
     by id;
run;

/*
ods rtf file="C:\JcohenBACKUP-Destination\toxico\whitepaper\All CEB Analyses\Diagnostics2\Malaoxon - individual sample curves.resids.rtf" startpage=no;
%scatter_plot(chemical=Malaoxon);
ods rtf close;
*/

*===> Human vs. Rat;

title "Human vs. Rat: final model 3";
*ods select  ParameterEstimates  FitStatistics ConvergenceStatus  AdditionalEstimates;
ods output ParameterEstimates=parm_HR;
PROC NLMIXED data=malaoxon  method=firo tech=newrap lis=3 maxiter=20000 /* gconv=0 */;
      PARMS ha=0.49
			hb=0.54
			ra=0.74
			rb=0.77
			gh1=0.7 gh12=0 gh2=0.8
			gr1=0.7 gr12=0 gr2=0.7
			S2E=0.4998;
			gha=gh1*gh1;
			ghab=gh1*gh12;
			ghb=gh12*gh12+gh2*gh2;
			gra=gr1*gr1;
			grab=gr1*gr12;
			grb=gr12*gr12+gr2*gr2;
            rha=ha+uha;
			rra=ra+ura;
            rhb=hb+uhb;
			rrb=rb+urb;
            PRED2 = (rha*H_I__M + rra*R_I__M)/(rhb*Human*1e-5 + H_I__M + rrb*Rat*1e-5 + R_I__M);
      MODEL KAPP ~ NORMAL(PRED2, S2E*1e-3);
      RANDOM  uha uhb ura urb ~ normal([0, 0, 0, 0],	[gha*1e-1, 
												 		 ghab*1e-1, ghb*1e-1,
														 0,    	  0,   gra*1e-1,
														 0,       0,   grab*1e-1, grb*1e-1]) SUBJECT=ID out=RandID_HR; 
	  ESTIMATE "human/rat" (ha/hb)/(ra/rb);
	  ESTIMATE 'human ki' (ha/hb);
      ESTIMATE 'rat ki' (ra/rb);
	  estimate "gha" gh1*gh1;
	  estimate "ghab" gh1*gh12;
	  estimate "ghb" gh12*gh12+gh2*gh2;
	  estimate "gra" gr1*gr1;
	  estimate "grab" gr1*gr12;
	  estimate "grb" gr12*gr12+gr2*gr2;
	  id pred2;
	  Predict PRED2 out=Resid_HR;
run;

%let factor=0.001;

ods rtf file="C:\JcohenBACKUP-Destination\toxico\whitepaper\All CEB Analyses\Diagnostics2\Malaoxon human-rat.resids.rtf" startpage=no;
%DiagnosticsHR(chemical=Malaoxon, model=3)
ods rtf close;
*%Calculate_Ki(chemical=TerbufosOxonSulfoxide, Hadj=1e-4, Radj=1e-4);

*===> Adult vs. Infant;
/* Using model 2 since could not get model 3 to converge */


title "final model 2b - Adult (>=10 yr) vs. Infant";
*ods select  ParameterEstimates  FitStatistics ConvergenceStatus  AdditionalEstimates;
ods output ParameterEstimates=parm_AI;
PROC NLMIXED data=malaoxon(where=(Human=1))  tech=nrridg lis=3 maxiter=1000 method=firo;
      PARMS ada=0.5380	adB=0.5377
			ia=0.3087 iB=0.6116
			ga1=0.6 	ga12=0	ga2=0.7
			S2E=0.5767;
			gada=ga1*ga1;
			gadab=ga1*ga12;
			gadb=ga12*ga12+ga2*ga2;
			rada=ada+uha;
			ria=ia+uha;
            radb=adB+uhb;
			rib=iB+uhb;
            PRED2 = (rada*H_I__M*adult + ria*H_I__M*infant)/(radb*adult*1e-5 + H_I__M*adult + rib*1e-5*infant + H_I__M*infant);
      MODEL KAPP ~ NORMAL(PRED2, S2E*1e-3);

     RANDOM  uha uhb ~ normal([0, 0],   [gada*1e-1, 
														gadab*1e-1, gadb*1e-1 
														]) SUBJECT=ID out=RandID_AI;
	 ESTIMATE "Adult/Infant ki" (ada/adb)/(ia/ib);
	  ESTIMATE 'Adult ki' (ada/adb);
      ESTIMATE 'Infant ki' (ia/ib);
  	  estimate "gada" ga1*ga1;
	  estimate "gadab" ga1*ga12;
	  estimate "gadb" ga12*ga12+ga2*ga2;
	  id pred2;
	   predict pred2 out=Resid_AI;
run;

%let factor=0.001;


ods rtf file="C:\JcohenBACKUP-Destination\toxico\whitepaper\All CEB Analyses\Diagnostics2\Malaoxon Adult-Infant.resids.rtf" startpage=no;
%DiagnosticsAI(chemical=Malaoxon, model=2)
ods rtf close;

*===> Male vs. Female;

title "final model 2b - male vs. female";
*ods select  ParameterEstimates  FitStatistics ConvergenceStatus  AdditionalEstimates;
ods output ParameterEstimates=parm_MF;
PROC NLMIXED data=Malaoxon(where=(Human=1)) method=firo  tech=newrap lis=3 maxiter=100000 method=firo;
      PARMS ma=0.5287 mb= 0.6603
			fa=.4667 fB=0.4465
			gh1=0.6 gh12=0 gh2=0.6
			S2E=.2649;
			gha=gh1*gh1;
			ghab=gh1*gh12;
			ghb=gh12*gh12+gh2*gh2;
            rma=ma+uha;
			rfa=fa+uha;
            rmb=mB+uhb;
			rfb=fB+uhb;
           PRED2 = (rma*H_I__M*male + rfa*H_I__M*female)/(rmb*male*1e-5 + H_I__M*male + rfb*female*1e-5 + H_I__M*female);
      MODEL KAPP ~ NORMAL(PRED2, S2E*1e-3);
      RANDOM  uha uhb ~ normal([0, 0],  [gha*1e-1, ghab*1e-1, ghb*1e-1]) SUBJECT=ID out=RandID_MF; 
	 ESTIMATE "male/female ki" (ma/mb)/(fa/fb);
	  ESTIMATE 'male ki' (ma/mb);
      ESTIMATE 'female ki' (fa/fb);
  	  estimate "gha" gh1*gh1;
	  estimate "ghab" gh1*gh12;
	  estimate "ghb" gh12*gh12+gh2*gh2;
	  id pred2;
	  predict pred2 out=Resid_MF;
run;

%let factor=0.001;

ods rtf file="C:\JcohenBACKUP-Destination\toxico\whitepaper\All CEB Analyses\Diagnostics2\Malaoxon Male-Female.resids.rtf" startpage=no;
%DiagnosticsMF(chemical=Malaoxon, model=2)
ods rtf close;


*===> Caucasian vs. Other Races;

title "Final model 2 - Caucasian vs. Other Race";
*ods select  ParameterEstimates  FitStatistics ConvergenceStatus  AdditionalEstimates;
ods output ParameterEstimates=parm_CO;
PROC NLMIXED data=Malaoxon(where=(Human=1)) method=firo  tech=newrap lis=3 maxiter=100000;
      PARMS ca=.5087 cb=.4956
			ora=0.4610 orB=0.6665
			gh1=0.6 gh12=0 gh2=0.7
			S2E=.5822;
			gha=gh1*gh1;
			ghab=gh1*gh12;
			ghb=gh12*gh12+gh2*gh2;
            rca=ca+uha;
			rora=ora+uha;
            rcb=cB+uhb;
			rorb=orB+uhb;
		PRED2 = (rca*H_I__M*caucasian + rora*H_I__M*otherrace)/(rcb*caucasian*1e-5 + H_I__M*caucasian + rorb*otherrace*1e-5 + H_I__M*otherrace);
      MODEL KAPP ~ NORMAL(PRED2, S2E*1e-3);
      RANDOM  uha uhb ~ normal([0, 0],  [gha*1e-1, ghab*1e-1, ghb*1e-1]) SUBJECT=ID out=RandID_CO;
	 ESTIMATE "Caucasian/Other Race ki" (ca/cb)/(ora/orb);
	  ESTIMATE 'Caucasain ki' (ca/cb);
      ESTIMATE 'Other Race ki' (ora/orb);
  	  estimate "gha" gh1*gh1;
	  estimate "ghab" gh1*gh12;
	  estimate "ghb" gh12*gh12+gh2*gh2;
	  id pred2;
	  predict pred2 out=Resid_CO;
run;

%let factor=0.001;

ods rtf file="C:\JcohenBACKUP-Destination\toxico\whitepaper\All CEB Analyses\Diagnostics2\Malaoxon Caucasian-Other Races.resids.rtf" startpage=no;
%DiagnosticsCO(chemical=Malaoxon, model=2)
ods rtf close;

%resids